@@ -9,33 +9,37 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    STREET_PREFIX = %w( Rua Avenida Travessa Alameda )
+    STREET_PREFIX = %w[Rua Avenida Travessa Alameda].freeze
 
     def zip_code
       FFaker.numerify '#####-###'
     end
 
     def state
-      STATE.sample
+      fetch_sample(STATE)
     end
 
     def state_abbr
-      STATE_ABBR.sample
+      fetch_sample(STATE_ABBR)
     end
 
     def city
-      CITY.sample
+      fetch_sample(CITY)
     end
 
     def street_prefix
-      STREET_PREFIX.sample
+      fetch_sample(STREET_PREFIX)
     end
 
     def street
-      case rand(1)
+      case rand(0..1)
       when 0 then "#{street_prefix} #{NameBR.name}"
       when 1 then "#{street_prefix} #{NameBR.first_name} #{NameBR.last_name} #{NameBR.last_name}"
       end
     end
+
+    def full_address
+      "#{street}, #{building_number}, #{city}, #{state}, Brazil"
+    end
   end
 end
