@@ -9,13 +9,12 @@ module FFaker
     extend ModuleUtils
     extend self
 
-
     def postal_code
       FFaker.numerify '####'
     end
 
     def canton_abbr
-      CANTON_ABBR.sample
+      fetch_sample(CANTON_ABBR)
     end
   end
 end
