@@ -9,7 +9,7 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    REGION = %w(Hovedstaden Sjælland Syddanmark Midtjylland Nordjylland)
+    REGION = %w[Hovedstaden Sjælland Syddanmark Midtjylland Nordjylland].freeze
     STATE = REGION
 
     def zip_code
@@ -25,23 +25,23 @@ module FFaker
     end
 
     def kommune
-      KOMMUNE.sample
+      fetch_sample(KOMMUNE)
     end
 
     def region
-      REGION.sample
+      fetch_sample(REGION)
     end
 
     def city
-      CITY.sample
+      fetch_sample(CITY)
     end
 
     def street_name
-      STREET.sample
+      fetch_sample(STREET)
     end
 
     def street_address
-      "#{street_name} #{rand(100)}"
+      "#{street_name} #{rand(0..99)}"
     end
 
     def full_address
