@@ -13,19 +13,18 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    ZIP_FORMATS = ['#####']
-    STREET_NBR_FORMATS = ['##', '#', '# a', '# b', '###', '# a #', '# b #']
+    STREET_NBR_FORMATS = ['##', '#', '# a', '# b', '###', '# a #', '# b #'].freeze
 
     def zip_code
-      FFaker.numerify ZIP_FORMATS.sample
+      FFaker.numerify('#####')
     end
 
     def city
-      CITY.sample
+      fetch_sample(CITY)
     end
 
     def street_name
-      STREET.sample
+      fetch_sample(STREET)
     end
 
     def street_address
@@ -33,7 +32,7 @@ module FFaker
     end
 
     def street_nbr
-      FFaker.numerify STREET_NBR_FORMATS.sample
+      FFaker.numerify(fetch_sample(STREET_NBR_FORMATS))
     end
 
     def full_address
@@ -41,8 +40,7 @@ module FFaker
     end
 
     def random_country
-      COUNTRIES.sample
+      fetch_sample(COUNTRIES)
     end
-
   end
 end
