@@ -9,48 +9,46 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    ZIP_FORMATS = ['######']
-
-    def pincode
-      FFaker.numerify ZIP_FORMATS.sample
+    def zip_code
+      FFaker.numerify('######')
     end
 
-    alias_method :zip_code, :pincode
+    alias pincode zip_code
 
     def state
-      STATE.sample
+      fetch_sample(STATE)
     end
 
     def state_abbr
-      STATE_ABBR.sample
+      fetch_sample(STATE_ABBR)
     end
 
     def union_territory
-      UNION_TERRITORY.sample
+      fetch_sample(UNION_TERRITORY)
     end
 
     def union_territory_abbr
-      UNION_TERRITORY_ABBR.sample
+      fetch_sample(UNION_TERRITORY_ABBR)
     end
 
     def state_and_union_territory
-      (STATE + UNION_TERRITORY).sample
+      fetch_sample(STATE + UNION_TERRITORY)
     end
 
     def state_and_union_territory_abbr
-      (STATE_ABBR + UNION_TERRITORY_ABBR).sample
+      fetch_sample(STATE_ABBR + UNION_TERRITORY_ABBR)
     end
 
     def country
-      FFaker::Address.country("IN")
+      FFaker::Address.country('IN')
     end
 
     def country_code
-      FFaker::Address.country_code("India")
+      FFaker::Address.country_code('India')
     end
 
     def time_zone
-      "Asia/Kolkata"
+      'Asia/Kolkata'
     end
   end
 end
