@@ -9,15 +9,15 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    POSTAL_CODE_FORMAT = ['######']
-    STREET_NBR_FORMATS = %w(## # ###)
+    POSTAL_CODE_FORMAT = ['######'].freeze
+    STREET_NBR_FORMATS = %w[## # ###].freeze
 
     def city
-      CITY.sample
+      fetch_sample(CITY)
     end
 
     def province
-      PROVINCE.sample
+      fetch_sample(PROVINCE)
     end
 
     def zip_code
@@ -25,7 +25,7 @@ module FFaker
     end
 
     def street_name
-      STREET.sample
+      fetch_sample(STREET)
     end
 
     def street_address
@@ -36,4 +36,4 @@ module FFaker
       FFaker.numerify(STREET_NBR_FORMATS)
     end
   end
-end
\ No newline at end of file
+end
