@@ -3,7 +3,6 @@
 require 'ffaker/address'
 
 module FFaker
-
   # List of countries from http://sv.wikipedia.org/wiki/V%C3%A4rldens_l%C3%A4nder#Lista_.C3.B6ver_l.C3.A4nder
   # The streetnames are all the roads in Stockholm that contains "väg" or "gata"
   # List of cities are from http://sv.wikipedia.org/wiki/Sveriges_kommuner
@@ -13,19 +12,19 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    ZIP_FORMATS = ['#####', '## ###']
-    STREET_NBR_FORMATS = ['##', '#', '#a', '#b', '###']
+    ZIP_FORMATS = ['#####', '## ###'].freeze
+    STREET_NBR_FORMATS = ['##', '#', '#a', '#b', '###'].freeze
 
     def zip_code
-      FFaker.numerify ZIP_FORMATS.sample
+      FFaker.numerify(fetch_sample(ZIP_FORMATS))
     end
 
     def city
-      CITY.sample
+      fetch_sample(CITY)
     end
 
     def street_name
-      STREET.sample
+      fetch_sample(STREET)
     end
 
     def street_address
@@ -33,7 +32,7 @@ module FFaker
     end
 
     def street_nbr
-      FFaker.numerify STREET_NBR_FORMATS.sample
+      FFaker.numerify(fetch_sample(STREET_NBR_FORMATS))
     end
 
     def full_address
@@ -41,7 +40,7 @@ module FFaker
     end
 
     def random_country
-      COUNTRIES.sample
+      fetch_sample(COUNTRIES)
     end
   end
 end
