@@ -9,19 +9,19 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    COUNTRY = ['England', 'Scotland', 'Wales', 'Northern Ireland']
-    POSTCODE = ['??# #??', '??## #??']
+    COUNTRY = ['England', 'Scotland', 'Wales', 'Northern Ireland'].freeze
+    POSTCODE = ['??# #??', '??## #??'].freeze
 
     def county
-      COUNTY.sample
+      fetch_sample(COUNTY)
     end
 
     def country
-      COUNTRY.sample
+      fetch_sample(COUNTRY)
     end
 
     def postcode
-      FFaker.bothify(POSTCODE.sample).upcase
+      FFaker.bothify(fetch_sample(POSTCODE)).upcase
     end
   end
 end
