@@ -6,13 +6,13 @@ module FFaker
     extend self
 
     def maybe
-      case rand(2)
+      case rand(0..1)
       when 0 then true
       when 1 then false
       end
     end
 
-    alias_method :random, :maybe
-    alias_method :sample, :maybe
+    alias random maybe
+    alias sample maybe
   end
 end
