@@ -5,19 +5,19 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    SUFFIXES = %w(AB Aktiebolag Ab)
+    SUFFIXES = %w[AB Aktiebolag Ab].freeze
 
     def name
-      case rand(3)
+      case rand(0..3)
       when 0 then "#{NameSE.last_name} #{suffix}"
       when 1 then "#{NameSE.last_name}-#{NameSE.last_name}"
-      when 1 then "#{NameSE.last_name}-#{NameSE.last_name} #{suffix}"
-      when 2 then "#{NameSE.last_name}, #{NameSE.last_name} och #{NameSE.last_name}"
+      when 2 then "#{NameSE.last_name}-#{NameSE.last_name} #{suffix}"
+      when 3 then "#{NameSE.last_name}, #{NameSE.last_name} och #{NameSE.last_name}"
       end
     end
 
     def suffix
-      SUFFIXES.sample
+      fetch_sample(SUFFIXES)
     end
   end
 end
