@@ -2,12 +2,11 @@
 
 module FFaker
   module CoursesFR
-
     module Mathematiques
       extend ModuleUtils
       extend self
       def lesson
-        LESSONS.sample
+        fetch_sample(LESSONS)
       end
     end
 
@@ -15,7 +14,7 @@ module FFaker
       extend ModuleUtils
       extend self
       def lesson
-        LESSONS.sample
+        fetch_sample(LESSONS)
       end
     end
   end
