@@ -4,24 +4,23 @@ module FFaker
     extend self
 
     def ingredient
-      self.send( %w(vegetable fruit meat herb_or_spice)[rand 4] )
+      send(%w[vegetable fruit meat herb_or_spice][rand 4])
     end
 
     def vegetable
-      VEGETABLE.sample
+      fetch_sample(VEGETABLE)
     end
 
     def fruit
-      FRUIT.sample
+      fetch_sample(FRUIT)
     end
 
     def meat
-      MEAT.sample
+      fetch_sample(MEAT)
     end
 
     def herb_or_spice
-      HERB_SPICE.sample
+      fetch_sample(HERB_SPICE)
     end
-
   end
 end
