@@ -5,8 +5,8 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    ETHNICITIES = ['African American', 'Asian/Pacific Islander', 'Caucasian', 'Hispanic', 'Native American', 'Multiracial', 'Other', 'Prefer not to respond']
-    GENDERS = %w(Male Female)
+    ETHNICITIES = ['African American', 'Asian/Pacific Islander', 'Caucasian', 'Hispanic', 'Native American', 'Multiracial', 'Other', 'Prefer not to respond'].freeze
+    GENDERS = %w[Male Female].freeze
 
     def drivers_license
       FFaker.bothify('?###-###-##-###-#').upcase
@@ -17,11 +17,11 @@ module FFaker
     end
 
     def ethnicity
-      ETHNICITIES.sample
+      fetch_sample(ETHNICITIES)
     end
 
     def gender
-      GENDERS.sample
+      fetch_sample(GENDERS)
     end
   end
 end
