@@ -5,10 +5,10 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    GENDERS = %w(Hombre Mujer)
+    GENDERS = %w[Hombre Mujer].freeze
 
     def gender
-      GENDERS.sample
+      fetch_sample(GENDERS)
     end
   end
 end
