@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # encoding: utf-8
 
 module FFaker
@@ -6,7 +7,7 @@ module FFaker
     extend self
 
     def title
-      JOB_NOUNS.sample
+      fetch_sample(JOB_NOUNS)
     end
   end
 end
