@@ -7,19 +7,19 @@ module FFaker
     extend self
 
     def characters(character_count = 255)
-      Array.new(character_count < 0 ? 0 : character_count).map { CHARACTERS.sample }.join
+      Array.new(character_count < 0 ? 0 : character_count).map { fetch_sample(CHARACTERS) }.join
     end
 
     def word
-      WORDS.sample
+      fetch_sample(WORDS)
     end
 
     def words(num = 3)
-      WORDS.sample(num)
+      fetch_sample(WORDS, count: num)
     end
 
     def sentence(word_count = 4)
-      first_word, *last_words = words(word_count + rand(5) + 1)
+      first_word, *last_words = words(word_count + rand(1..5))
       if last_words.nil?
         first_word.capitalize
       else
@@ -27,16 +27,16 @@ module FFaker
       end
     end
 
-    alias_method :phrase, :sentence
+    alias phrase sentence
 
     def sentences(sentence_count = 3)
       (1..sentence_count).map { sentence }
     end
 
-    alias_method :phrases, :sentences
+    alias phrases sentences
 
     def paragraph(sentence_count = 3)
-      sentences(sentence_count + rand(3)).join(' ')
+      sentences(sentence_count + rand(0..2)).join(' ')
     end
 
     def paragraphs(paragraph_count = 3)
