@@ -7,15 +7,15 @@ module FFaker
     extend self
 
     def word
-      WORDS.sample
+      fetch_sample(WORDS)
     end
 
     def words(num = 3)
-      WORDS.sample(num)
+      fetch_sample(WORDS, count: num)
     end
 
     def sentence(word_count = 4)
-      s = words(word_count + rand(6))
+      s = words(word_count + rand(0..5))
       s = s.join
       "#{s},"
     end
@@ -23,7 +23,7 @@ module FFaker
     def sentences(sentence_count = 3)
       s = (1..sentence_count).map { sentence }
       def s.to_s
-        result = self.join(' ')
+        result = join(' ')
         result[-1] = '。'
         result
       end
@@ -31,7 +31,7 @@ module FFaker
     end
 
     def paragraph(sentence_count = 3)
-      sentences(sentence_count + rand(3)).to_s
+      sentences(sentence_count + rand(0..2)).to_s
     end
 
     def paragraphs(paragraph_count = 3)
