@@ -6,27 +6,27 @@ module FFaker
     extend self
 
     def word
-      WORDS.sample
+      fetch_sample(WORDS)
     end
 
     def words(num = 3)
-      WORDS.sample(num)
+      fetch_sample(WORDS, count: num)
     end
 
     def sentence(word_count = 4)
-      "#{words(word_count + rand(5) + 1).join(' ')}."
+      "#{words(word_count + rand(1..5)).join(' ')}."
     end
 
-    alias_method :phrase, :sentence
+    alias phrase sentence
 
     def sentences(sentence_count = 3)
       (1..sentence_count).map { sentence }
     end
 
-    alias_method :phrases, :sentences
+    alias phrases sentences
 
     def paragraph(sentence_count = 3)
-      sentences(sentence_count + rand(3)).join(' ')
+      sentences(sentence_count + rand(0..2)).join(' ')
     end
 
     def paragraphs(paragraph_count = 3)
