@@ -6,32 +6,30 @@ module FFaker
     extend self
 
     def word
-      WORDS.sample
+      fetch_sample(WORDS)
     end
 
     def words(num = 3)
-      WORDS.sample(num)
+      fetch_sample(WORDS, count: num)
     end
 
     def sentence(word_count = 7)
-      elements = words(word_count + rand(10))
-      if elements.count > 10
-        elements.insert(rand(3..(elements.count - 3)), ',')
-      end
+      elements = words(word_count + rand(0..9))
+      elements.insert(rand(3..(elements.count - 3)), ',') if elements.count > 10
       result = elements.join(' ').gsub(' , ', ', ')
       capitalize_ukrainian("#{result}#{sentence_type_mark}")
     end
 
-    alias_method :phrase, :sentence
+    alias phrase sentence
 
     def sentences(sentence_count = 3)
       (1..sentence_count).map { sentence }
     end
 
-    alias_method :phrases, :sentences
+    alias phrases sentences
 
     def paragraph(sentence_count = 5)
-      sentences(sentence_count + rand(3)).join(' ')
+      sentences(sentence_count + rand(0..2)).join(' ')
     end
 
     def paragraphs(paragraph_count = 3)
@@ -41,10 +39,10 @@ module FFaker
     private
 
     def sentence_type_mark
-      case rand(10)
-      when 0..7 then "."
-      when 8    then "!"
-      when 9    then "?"
+      case rand(0..9)
+      when 0..7 then '.'
+      when 8    then '!'
+      when 9    then '?'
       end
     end
 
@@ -56,4 +54,3 @@ module FFaker
     end
   end
 end
-
