@@ -9,7 +9,7 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    PREFIXES = %w(Hr. Fr. Dr. Prof.)
+    PREFIXES = %w[Hr. Fr. Dr. Prof.].freeze
 
     def name(gender = :any)
       generate_name(first_name(gender))
@@ -29,26 +29,26 @@ module FFaker
 
     def first_name(gender = :any)
       case gender
-      when :any then (rand(2) == 0) ? first_name(:male) : first_name(:female)
-      when :male then MALE_FIRST_NAMES.sample
-      when :female then FEMALE_FIRST_NAMES.sample
+      when :any then rand(0..1) == 0 ? first_name(:male) : first_name(:female)
+      when :male then fetch_sample(MALE_FIRST_NAMES)
+      when :female then fetch_sample(FEMALE_FIRST_NAMES)
       else
-        fail ArgumentError, 'Invalid gender, must be one of :any, :male, :female'
+        raise ArgumentError, 'Invalid gender, must be one of :any, :male, :female'
       end
     end
 
     def last_name
-      LAST_NAMES.sample
+      fetch_sample(LAST_NAMES)
     end
 
     def prefix
-      PREFIXES.sample
+      fetch_sample(PREFIXES)
     end
 
     private
 
     def generate_name(first_name)
-      case rand(8)
+      case rand(0..7)
       when 0    then "#{prefix} #{first_name} #{last_name}"
       when 1..2 then "#{first_name} #{last_name} #{last_name}"
       else           "#{first_name} #{last_name}"
