@@ -9,25 +9,25 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    PREFIXES = %w(Herr Frau Dr. Prof.)
+    PREFIXES = %w[Herr Frau Dr. Prof.].freeze
 
     def name
-      case rand(10)
+      case rand(0..9)
       when 0 then "#{prefix} #{first_name} #{last_name}"
-      else 	  "#{first_name} #{last_name}"
+      else "#{first_name} #{last_name}"
       end
     end
 
     def first_name
-      FIRST_NAMES.sample
+      fetch_sample(FIRST_NAMES)
     end
 
     def last_name
-      LAST_NAMES.sample
+      fetch_sample(LAST_NAMES)
     end
 
     def prefix
-      PREFIXES.sample
+      fetch_sample(PREFIXES)
     end
   end
 end
