@@ -8,28 +8,26 @@ module FFaker
     extend ModuleUtils
     extend self
 
-    PREFIX = %w(de du le)
+    PREFIX = %w[de du le].freeze
 
     # randomized? (FRENCH)  prefix!
     #
     def prefix
-      PREFIX.sample
+      fetch_sample(PREFIX)
     end
 
     def last_name
-      LAST_NAMES.sample
+      fetch_sample(LAST_NAMES)
     end
 
     def first_name
-      FIRST_NAMES.sample
+      fetch_sample(FIRST_NAMES)
     end
 
     def name
-      case rand(10)
+      case rand(0..9)
       when 7 then "#{first_name} #{prefix} #{last_name}"
       when 5 then "#{first_name} #{prefix} #{last_name}"
-      when 3 then "#{first_name} #{last_name}"
-      when 0 then "#{first_name} #{last_name}"
       else        "#{first_name} #{last_name}"
       end
     end
