@@ -1,25 +1,24 @@
 # encoding: utf-8
 
 module FFaker
-
   # Generates names from Gambia West Africa
   # Source: http://www.columbia.edu/~msj42/Common%20Gambian%20First%20Names.htm
   module NameGA
     extend ModuleUtils
     extend self
 
-    LAST_NAMES = %w(jammeh ceesay)
+    LAST_NAMES = %w[jammeh ceesay].freeze
 
     def first_name_female
-      FIRST_NAMES_FEMALE.sample
+      fetch_sample(FIRST_NAMES_FEMALE)
     end
 
     def first_name_male
-      FIRST_NAMES_MALE.sample
+      fetch_sample(FIRST_NAMES_MALE)
     end
 
     def last_name
-      LAST_NAMES.sample
+      fetch_sample(LAST_NAMES)
     end
 
     def name_male
@@ -31,15 +30,8 @@ module FFaker
     end
 
     def name
-      case rand(10)
-      when 9 then name_female
-      when 8 then name_male
-      when 7 then name_female
-      when 6 then name_male
-      when 5 then name_female
-      when 4 then name_male
-      when 3 then name_female
-      when 2 then name_male
+      case rand(0..1)
+      when 1 then name_male
       else name_female
       end
     end
