@@ -6,17 +6,17 @@ module FFaker
     extend self
 
     def first_name
-      FIRST_NAMES.sample
+      fetch_sample(FIRST_NAMES)
     end
 
     def last_name
-      LAST_NAMES.sample
+      fetch_sample(LAST_NAMES)
     end
 
     def last_first
       "#{last_name}#{first_name}"
     end
 
-    alias_method :name, :last_first
+    alias name last_first
   end
 end
