@@ -14,13 +14,13 @@ module FFaker
     end
 
     def first_name
-      FIRST_NAMES.sample
+      fetch_sample(FIRST_NAMES)
     end
 
     def last_name
-      LAST_NAMES.sample
+      fetch_sample(LAST_NAMES)
     end
 
-    alias_method :last_first, :name
+    alias last_first name
   end
 end
