@@ -10,19 +10,19 @@ module FFaker
     end
 
     def first_name
-      FIRST_NAMES.sample
+      fetch_sample(FIRST_NAMES)
     end
 
     def last_name
-      LAST_NAMES.sample
+      fetch_sample(LAST_NAMES)
     end
 
     def middle_name
-      MIDDLE_NAMES.sample
+      fetch_sample(MIDDLE_NAMES)
     end
 
     def last_first
-       "#{last_name} #{middle_name} #{first_name}"
+      "#{last_name} #{middle_name} #{first_name}"
     end
   end
 end
