@@ -10,26 +10,26 @@ module FFaker
     #  xx xxxx xxxx
     #
     def home_work_phone_number
-      FFaker.numerify("## #### ####")
+      FFaker.numerify('## #### ####')
     end
 
     # Generates a mobile phone number
     # 044 xx xxxx xxxx
     #
     def mobile_phone_number
-      FFaker.numerify("044 ## #### ####")
+      FFaker.numerify('044 ## #### ####')
     end
 
     # generates mobile or home/work number
     def phone_number
-      case rand(2)
+      case rand(0..1)
       when 0 then home_work_phone_number
       when 1 then mobile_phone_number
       end
     end
 
     def country_code
-      "+52"
+      '+52'
     end
 
     def international_mobile_phone_number
@@ -41,7 +41,7 @@ module FFaker
     end
 
     def international_phone_number
-      case rand(2)
+      case rand(0..1)
       when 0 then international_mobile_phone_number
       when 1 then international_home_work_phone_number
       end
@@ -51,8 +51,7 @@ module FFaker
     #  01 800 xxx xxxx
     #
     def toll_free_number
-      FFaker.numerify("01 800 ### ####")
+      FFaker.numerify('01 800 ### ####')
     end
-
   end
 end
