@@ -6,15 +6,15 @@ module FFaker
     extend self
 
     def tech_skill
-      TECH_SKILLS.sample
+      fetch_sample(TECH_SKILLS)
     end
 
     def tech_skills(num = 3)
-      TECH_SKILLS.sample(num)
+      fetch_sample(TECH_SKILLS, count: num)
     end
 
     def specialty
-      "%s %s" % [SPECIALTY_START.sample, SPECIALTY_END.sample]
+      format('%s %s', fetch_sample(SPECIALTY_START), fetch_sample(SPECIALTY_END))
     end
 
     def specialties(num = 3)
