@@ -1,5 +1,8 @@
+require 'ffaker/utils/random_utils'
 module FFaker
   module ArrayUtils
+    extend RandomUtils
+
     def self.const_array(argument)
       array = argument.is_a?(Array) ? argument : argument.to_a
       array.extend ArrayUtils
@@ -7,13 +10,13 @@ module FFaker
     end
 
     def self.random_pick(array, n)
-      warn '[ArrayUtils.random_pick] is deprecated. Please use the Array#sample method'
-      array.sample(n)
+      warn '[ArrayUtils.random_pick] is deprecated. Please use the ModuleUtils#fetch_sample method'
+      fetch_sample(array, count: n)
     end
 
     def self.rand(array)
-      warn '[ArrayUtils.rand] is deprecated. Please use the Array#sample method'
-      array.sample
+      warn '[ArrayUtils.rand] is deprecated. Please use the ModuleUtils#fetch_sample method'
+      fetch_sample(array)
     end
 
     def self.freeze_all(array)
@@ -23,17 +26,17 @@ module FFaker
     end
 
     def self.shuffle(array)
-      array.sort_by{Kernel.rand}
+      array.sort_by { FFaker::Random.rand }
     end
 
     def random_pick(n)
-      warn '[ArrayUtils#random_pick] is deprecated. Please use the Array#sample method'
-      self.sample(n)
+      warn '[ArrayUtils#random_pick] is deprecated. Please use the ModuleUtils#fetch_sample method'
+      ArrayUtils.random_pick(self, n)
     end
 
     def rand
-      warn '[ArrayUtils#rand] is deprecated. Please use the Array#sample method'
-      sample
+      warn '[ArrayUtils#rand] is deprecated. Please use the ModuleUtils#fetch_sample method'
+      ArrayUtils.rand(self)
     end
 
     def freeze_all
