@@ -3,8 +3,15 @@
 require 'helper'
 
 class TestAddressBR < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::AddressBR,
+    :zip_code, :state, :state_abbr, :city, :street_prefix, :street, :full_address
+  )
+
   def test_zip_code
-    assert_match /\d{5}-\d{3}/, FFaker::AddressBR.zip_code
+    assert_match(/\d{5}-\d{3}/, FFaker::AddressBR.zip_code)
   end
 
   def test_state
@@ -25,6 +32,6 @@ class TestAddressBR < Test::Unit::TestCase
 
   def test_street
     prefixes = FFaker::AddressBR::STREET_PREFIX
-    assert_match /(#{prefixes.join('|')})( [\p{Alpha}]+){1,2}/, FFaker::AddressBR.street
+    assert_match(/(#{prefixes.join('|')})( [\p{Alpha}]+){1,2}/, FFaker::AddressBR.street)
   end
 end
