@@ -3,6 +3,13 @@
 require 'helper'
 
 class TestAddressCA < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::AddressCA,
+    :province, :province_abbr, :city, :postal_code
+  )
+
   def test_province
     assert_match(/\A[ a-z]+\z/i, FFaker::AddressCA.province)
   end
@@ -18,6 +25,7 @@ class TestAddressCA < Test::Unit::TestCase
   def test_postal_code
     assert_match(
       /\A[A-CEGHJK-NPR-TVXY]\d[A-CEGHJK-NPR-TV-Z] \d[A-CEGHJK-NPR-TV-Z]\d\z/,
-      FFaker::AddressCA.postal_code)
+      FFaker::AddressCA.postal_code
+    )
   end
 end
