@@ -3,12 +3,18 @@
 require 'helper'
 
 class TestAddressSE < Test::Unit::TestCase
+  include DeterministicHelper
 
   ALPHA = /\A[\p{Alpha}]+/
   DIGIT = /\d{1}/
 
+  assert_methods_are_deterministic(
+    FFaker::AddressSE,
+    :city, :random_country, :full_address, :zip_code
+  )
+
   def test_se_city
-    assert_match ALPHA, FFaker::AddressSE.city
+    assert_match(ALPHA, FFaker::AddressSE.city)
   end
 
   def test_se_zip_code
@@ -21,8 +27,8 @@ class TestAddressSE < Test::Unit::TestCase
 
   def test_se_full_address
     address = FFaker::AddressSE.full_address
-    assert_match ALPHA, address
-    assert_match DIGIT, address
+    assert_match(ALPHA, address)
+    assert_match(DIGIT, address)
     assert_match(/SVERIGE/, address)
     assert_match(/[\, a-z]/, address)
   end
