@@ -3,9 +3,15 @@
 # => author: PapePathe github.com/PapePathe
 # => email: pathe.sene@gmail.com
 
-require "helper"
+require 'helper'
 
 class TestAddressSn < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::AddressSN,
+    :region, :departement, :arrondissement
+  )
 
   def setup
     @subject = FFaker::AddressSN
