@@ -3,6 +3,12 @@
 require 'helper'
 
 class TestCompanySE < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::CompanySE,
+    :name, :suffix
+  )
 
   def test_name
     assert_match(/[ a-z]+/, FFaker::CompanySE.name)
