@@ -1,6 +1,10 @@
-require "helper"
+require 'helper'
 
 class TestCourseMathematiques < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(FFaker::CoursesFR::Mathematiques, :lesson)
+
   def setup
     @subject = FFaker::CoursesFR::Mathematiques
   end
