@@ -3,12 +3,19 @@
 require 'helper'
 
 class TestLoremCN < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::LoremCN,
+    :paragraph, :paragraphs, :sentence, :sentences, :word, :words
+  )
+
   def test_paragraph
-    assert FFaker::LoremCN.paragraph.length >= 3*4*2
+    assert FFaker::LoremCN.paragraph.length >= 3 * 4 * 2
   end
 
   def test_sentence
-    assert FFaker::LoremCN.sentence.length >= 4*2
+    assert FFaker::LoremCN.sentence.length >= 4 * 2
   end
 
   def test_paragraphs
