@@ -3,6 +3,13 @@
 require 'helper'
 
 class TestFakerNameCS < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::NameCS,
+    :name, :last_name, :first_name, :prefix, :suffix
+  )
+
   def setup
     @tester = FFaker::NameCS
   end
@@ -56,10 +63,10 @@ class TestFakerNameCS < Test::Unit::TestCase
 
   # checks if every name is of the same sex
   def same_sex?(words, sex = :any)
-    (sex == :any ? [:male, :female] : [sex]).any? do |sex|
+    (sex == :any ? %i[male female] : [sex]).any? do |s|
       words.all? do |word|
         [@tester::LAST_NAMES, @tester::FIRST_NAMES].any? do |names|
-          names[sex].include?(word)
+          names[s].include?(word)
         end
       end
     end
