@@ -3,6 +3,13 @@
 require 'helper'
 
 class TestFakerNameDA < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::NameDA,
+    :any_name, :male_name, :female_name, :last_name, :prefix
+  )
+
   RU_REGEX = /[А-Я][а-я]+/
 
   def setup
@@ -10,7 +17,9 @@ class TestFakerNameDA < Test::Unit::TestCase
   end
 
   def test_name
-    assert_raise { @tester.name(:hahaha) }
+    assert_raise(ArgumentError, 'Invalid gender, must be one of :any, :male, :female') do
+      @tester.name(:hahaha)
+    end
   end
 
   def test_any_name
@@ -18,15 +27,15 @@ class TestFakerNameDA < Test::Unit::TestCase
   end
 
   def test_male_name
-    regexp = %r(#{@tester::MALE_FIRST_NAMES.join('|')})
+    regexp = /#{@tester::MALE_FIRST_NAMES.join('|')}/
     assert @tester.male_name.count(' ') < 3
-    assert_match regexp, @tester.male_name
+    assert_match(regexp, @tester.male_name)
   end
 
   def test_female_name
-    regexp = %r(#{@tester::FEMALE_FIRST_NAMES.join('|')})
+    regexp = /#{@tester::FEMALE_FIRST_NAMES.join('|')}/
     assert @tester.female_name.count(' ') < 3
-    assert_match regexp, @tester.female_name
+    assert_match(regexp, @tester.female_name)
   end
 
   def test_first_name
@@ -35,14 +44,16 @@ class TestFakerNameDA < Test::Unit::TestCase
     first_names = @tester::MALE_FIRST_NAMES + @tester::FEMALE_FIRST_NAMES
     assert_include first_names, @tester.first_name(:any)
     assert_include first_names, @tester.first_name
-    assert_raise { @tester.first_name(:hahaha) }
+    assert_raise(ArgumentError, 'Invalid gender, must be one of :any, :male, :female') do
+      @tester.first_name(:hahaha)
+    end
   end
 
   def test_last_name
-    assert_match /\A['a-z]+\z/i, @tester.last_name
+    assert_match(/\A['a-z]+\z/i, @tester.last_name)
   end
 
   def test_prefix
-    assert_match /\A(?:Hr|Fr|Dr|Prof)\.\Z/, @tester.prefix
+    assert_match(/\A(?:Hr|Fr|Dr|Prof)\.\Z/, @tester.prefix)
   end
 end
