@@ -5,8 +5,8 @@ require 'helper'
 class TestFakerNameJA < Test::Unit::TestCase
   class << self
     def startup
-      FFaker::NameJA.const_set(:FIRST_NAMES, %w(あきら フミ 三郎))
-      FFaker::NameJA.const_set(:LAST_NAMES, %w(佐藤 高橋 佐々木))
+      FFaker::NameJA.const_set(:FIRST_NAMES, %w[あきら フミ 三郎])
+      FFaker::NameJA.const_set(:LAST_NAMES, %w[佐藤 高橋 佐々木])
     end
 
     def shutdown
@@ -15,6 +15,13 @@ class TestFakerNameJA < Test::Unit::TestCase
     end
   end
 
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::NameJA,
+    :last_name, :first_name, :last_first, :name
+  )
+
   def setup
     @tester = FFaker::NameJA
   end
