@@ -4,6 +4,13 @@ require 'helper'
 
 # Author: wiseleyb<wiseleyb@gmail.com>
 class TestPhoneNumberNL < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::PhoneNumberNL,
+    :mobile_phone_number, :phone_number, :international_phone_number
+  )
+
   def setup
     @tester = FFaker::PhoneNumberNL
   end
@@ -18,13 +25,13 @@ class TestPhoneNumberNL < Test::Unit::TestCase
 
   def test_phone_number
     10.times do
-      assert_match /^0([\s\-]*\d){9}$/, @tester.phone_number
+      assert_match(/^0([\s\-]*\d){9}$/, @tester.phone_number)
     end
   end
 
   def test_international_phone_number
     10.times do
-      assert_match /^\+31/, @tester.international_phone_number
+      assert_match(/^\+31/, @tester.international_phone_number)
     end
   end
 end
