@@ -3,9 +3,15 @@
 require 'helper'
 
 class TestSkill < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(
+    FFaker::Skill,
+    :tech_skill, :tech_skills, :specialty, :specialties
+  )
 
   def test_tech_skill
-    assert_match /[a-z]+/i, FFaker::Skill.tech_skill
+    assert_match(/[a-z]+/i, FFaker::Skill.tech_skill)
   end
 
   def test_tech_skills
@@ -14,7 +20,7 @@ class TestSkill < Test::Unit::TestCase
   end
 
   def test_specialty
-    assert_match /[ a-z]+/i, FFaker::Skill.specialty
+    assert_match(/[ a-z]+/i, FFaker::Skill.specialty)
   end
 
   def test_specialties
