@@ -3,6 +3,10 @@
 require 'helper'
 
 class TestSports < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(FFaker::Sport, :name)
+
   def setup
     @tester = FFaker::Sport
   end
