@@ -3,6 +3,9 @@
 require 'helper'
 
 class TestSSNSE < Test::Unit::TestCase
+  include DeterministicHelper
+
+  assert_methods_are_deterministic(FFaker::SSNSE, :ssn)
 
   def test_ssn_format
     ssn = FFaker::SSNSE.ssn
